"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    db_instance_identifier: str,
    db_instance_class: str,
    engine: str,
    db_cluster_identifier: str,
    availability_zone: str = None,
    preferred_maintenance_window: str = None,
    auto_minor_version_upgrade: bool = None,
    tags: List = None,
    promotion_tier: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new instance.

    Args:
        db_instance_identifier(str): The instance identifier. This parameter is stored as a lowercase string. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Example: mydbinstance .
        db_instance_class(str): The compute and memory capacity of the instance; for example, db.r5.large. .
        engine(str): The name of the database engine to be used for this instance. Valid value: docdb .
        availability_zone(str, optional): The Amazon EC2 Availability Zone that the instance is created in.  Default: A random, system-chosen Availability Zone in the endpoint's Region. Example: us-east-1d . Defaults to None.
        preferred_maintenance_window(str, optional): The time range each week during which system maintenance can occur, in Universal Coordinated Time (UTC).  Format: ddd:hh24:mi-ddd:hh24:mi  The default is a 30-minute window selected at random from an 8-hour block of time for each Region, occurring on a random day of the week.  Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun Constraints: Minimum 30-minute window. Defaults to None.
        auto_minor_version_upgrade(bool, optional): This parameter does not apply to Amazon DocumentDB. Amazon DocumentDB does not perform minor version upgrades regardless of the value set. Default: false . Defaults to None.
        tags(List, optional): The tags to be assigned to the instance. You can assign up to 10 tags to an instance. Defaults to None.
        db_cluster_identifier(str): The identifier of the cluster that the instance will belong to.
        promotion_tier(int, optional): A value that specifies the order in which an Amazon DocumentDB replica is promoted to the primary instance after a failure of the existing primary instance. Default: 1 Valid values: 0-15. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.instance.create(
                ctx,
                db_instance_identifier=value,
                db_instance_class=value,
                engine=value,
                db_cluster_identifier=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.instance.create db_instance_identifier=value, db_instance_class=value, engine=value, db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="create_db_instance",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "DBInstanceClass": db_instance_class,
            "Engine": engine,
            "AvailabilityZone": availability_zone,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "Tags": tags,
            "DBClusterIdentifier": db_cluster_identifier,
            "PromotionTier": promotion_tier,
        },
    )


async def delete(hub, ctx, db_instance_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a previously provisioned instance.

    Args:
        db_instance_identifier(str): The instance identifier for the instance to be deleted. This parameter isn't case sensitive. Constraints:   Must match the name of an existing instance.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.instance.delete(ctx, db_instance_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.instance.delete db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="delete_db_instance",
        op_kwargs={"DBInstanceIdentifier": db_instance_identifier},
    )


async def describe_all(
    hub,
    ctx,
    db_instance_identifier: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about provisioned Amazon DocumentDB instances. This API supports pagination.

    Args:
        db_instance_identifier(str, optional): The user-provided instance identifier. If this parameter is specified, information from only the specific instance is returned. This parameter isn't case sensitive. Constraints:   If provided, must match the identifier of an existing DBInstance.  . Defaults to None.
        filters(List, optional): A filter that specifies one or more instances to describe. Supported filters:    db-cluster-id - Accepts cluster identifiers and cluster Amazon Resource Names (ARNs). The results list includes only the information about the instances that are associated with the clusters that are identified by these ARNs.    db-instance-id - Accepts instance identifiers and instance ARNs. The results list includes only the information about the instances that are identified by these ARNs.  . Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token (marker) is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.instance.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.instance.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="describe_db_instances",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub,
    ctx,
    db_instance_identifier: str,
    db_instance_class: str = None,
    apply_immediately: bool = None,
    preferred_maintenance_window: str = None,
    auto_minor_version_upgrade: bool = None,
    new_db_instance_identifier: str = None,
    ca_certificate_identifier: str = None,
    promotion_tier: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies settings for an instance. You can change one or more database configuration parameters by specifying these parameters and the new values in the request.

    Args:
        db_instance_identifier(str): The instance identifier. This value is stored as a lowercase string. Constraints:   Must match the identifier of an existing DBInstance.  .
        db_instance_class(str, optional): The new compute and memory capacity of the instance; for example, db.r5.large. Not all instance classes are available in all Regions.  If you modify the instance class, an outage occurs during the change. The change is applied during the next maintenance window, unless ApplyImmediately is specified as true for this request.  Default: Uses existing setting. Defaults to None.
        apply_immediately(bool, optional): Specifies whether the modifications in this request and any pending modifications are asynchronously applied as soon as possible, regardless of the PreferredMaintenanceWindow setting for the instance.   If this parameter is set to false, changes to the instance are applied during the next maintenance window. Some parameter changes can cause an outage and are applied on the next reboot. Default: false . Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range (in UTC) during which system maintenance can occur, which might result in an outage. Changing this parameter doesn't result in an outage except in the following situation, and the change is asynchronously applied as soon as possible. If there are pending actions that cause a reboot, and the maintenance window is changed to include the current time, changing this parameter causes a reboot of the instance. If you are moving this window to the current time, there must be at least 30 minutes between the current time and end of the window to ensure that pending changes are applied. Default: Uses existing setting. Format: ddd:hh24:mi-ddd:hh24:mi  Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun Constraints: Must be at least 30 minutes. Defaults to None.
        auto_minor_version_upgrade(bool, optional): This parameter does not apply to Amazon DocumentDB. Amazon DocumentDB does not perform minor version upgrades regardless of the value set. Defaults to None.
        new_db_instance_identifier(str, optional):  The new instance identifier for the instance when renaming an instance. When you change the instance identifier, an instance reboot occurs immediately if you set Apply Immediately to true. It occurs during the next maintenance window if you set Apply Immediately to false. This value is stored as a lowercase string.  Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Example: mydbinstance . Defaults to None.
        ca_certificate_identifier(str, optional): Indicates the certificate that needs to be associated with the instance. Defaults to None.
        promotion_tier(int, optional): A value that specifies the order in which an Amazon DocumentDB replica is promoted to the primary instance after a failure of the existing primary instance. Default: 1 Valid values: 0-15. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.instance.modify(ctx, db_instance_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.instance.modify db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="modify_db_instance",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "DBInstanceClass": db_instance_class,
            "ApplyImmediately": apply_immediately,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "NewDBInstanceIdentifier": new_db_instance_identifier,
            "CACertificateIdentifier": ca_certificate_identifier,
            "PromotionTier": promotion_tier,
        },
    )


async def reboot(
    hub, ctx, db_instance_identifier: str, force_failover: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    You might need to reboot your instance, usually for maintenance reasons. For example, if you make certain changes, or if you change the cluster parameter group that is associated with the instance, you must reboot the instance for the changes to take effect.  Rebooting an instance restarts the database engine service. Rebooting an instance results in a momentary outage, during which the instance status is set to rebooting.

    Args:
        db_instance_identifier(str): The instance identifier. This parameter is stored as a lowercase string. Constraints:   Must match the identifier of an existing DBInstance.  .
        force_failover(bool, optional):  When true, the reboot is conducted through a Multi-AZ failover.  Constraint: You can't specify true if the instance is not configured for Multi-AZ. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.db.instance.reboot(ctx, db_instance_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.db.instance.reboot db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="reboot_db_instance",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "ForceFailover": force_failover,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def export(hub, ctx, backup_plan_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the backup plan that is specified by the plan ID as a backup template.

    Args:
        backup_plan_id(str): Uniquely identifies a backup plan.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.plan.template.export(ctx, backup_plan_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.plan.template.export backup_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="export_backup_plan_template",
        op_kwargs={"BackupPlanId": backup_plan_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata of your saved backup plan templates, including the template ID, name, and the creation and deletion dates.

    Args:
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.plan.template.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.plan.template.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_backup_plan_templates",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the status and details of an events detection job.

    Args:
        job_id(str): The identifier of the events detection job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.event_detection_job.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.event_detection_job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="describe_events_detection_job",
        op_kwargs={"JobId": job_id},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the events detection jobs that you have submitted.

    Args:
        filter_(Dict, optional): Filters the jobs that are returned. You can filter jobs on their name, status, or the date and time that they were submitted. You can only set one filter at a time. Defaults to None.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional): The maximum number of results to return in each page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.event_detection_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.event_detection_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="list_events_detection_jobs",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    input_data_config: Dict,
    output_data_config: Dict,
    data_access_role_arn: str,
    language_code: str,
    target_event_types: List,
    job_name: str = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an asynchronous event detection job for a collection of documents.

    Args:
        input_data_config(Dict): Specifies the format and location of the input data for the job.
        output_data_config(Dict): Specifies where to send the output files.
        data_access_role_arn(str): The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants Amazon Comprehend read access to your input data.
        job_name(str, optional): The identifier of the events detection job. Defaults to None.
        language_code(str): The language code of the input documents.
        client_request_token(str, optional): An unique identifier for the request. If you don't set the client request token, Amazon Comprehend generates one. Defaults to None.
        target_event_types(List): The types of events to detect in the input documents.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.event_detection_job.start(
                ctx,
                input_data_config=value,
                output_data_config=value,
                data_access_role_arn=value,
                language_code=value,
                target_event_types=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.event_detection_job.start input_data_config=value, output_data_config=value, data_access_role_arn=value, language_code=value, target_event_types=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="start_events_detection_job",
        op_kwargs={
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "DataAccessRoleArn": data_access_role_arn,
            "JobName": job_name,
            "LanguageCode": language_code,
            "ClientRequestToken": client_request_token,
            "TargetEventTypes": target_event_types,
        },
    )


async def stop(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops an events detection job in progress.

    Args:
        job_id(str): The identifier of the events detection job to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.event_detection_job.stop(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.event_detection_job.stop job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="stop_events_detection_job",
        op_kwargs={"JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def test(hub, ctx, event_pattern: str, event: str) -> Dict:
    r"""
    **Autogenerated function**

    Tests whether the specified event pattern matches the provided event. Most services in AWS treat : or / as the same character in Amazon Resource Names (ARNs). However, EventBridge uses an exact match in event patterns and rules. Be sure to use the correct ARN characters when creating event patterns so that they match the ARN syntax in the event you want to match.

    Args:
        event_pattern(str): The event pattern. For more information, see Events and Event Patterns in the Amazon EventBridge User Guide.
        event(str): The event, in JSON format, to test against the event pattern. The JSON must follow the format specified in AWS Events, and the following fields are mandatory:    id     account     source     time     region     resources     detail-type   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.pattern.test(ctx, event_pattern=value, event=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.pattern.test event_pattern=value, event=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="test_event_pattern",
        op_kwargs={"EventPattern": event_pattern, "Event": event},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, fleet_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a fleet's runtime configuration settings. The runtime configuration tells GameLift which server processes to run (and how) on each instance in the fleet. To get the runtime configuration that is currently in forces for a fleet, provide the fleet ID.  If successful, a RuntimeConfiguration object is returned for the requested fleet. If the requested fleet has been deleted, the result set is empty.  Learn more   Setting up GameLift fleets   Running multiple processes on a fleet   Related actions   ListFleets | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetEvents | DescribeFleetLocationAttributes | DescribeFleetPortSettings | DescribeFleetUtilization | DescribeRuntimeConfiguration | DescribeScalingPolicies | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to get the runtime configuration for. You can use either the fleet ID or ARN value.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.runtime_configuration.describe(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.runtime_configuration.describe fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_runtime_configuration",
        op_kwargs={"FleetId": fleet_id},
    )


async def update(hub, ctx, fleet_id: str, runtime_configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates the current runtime configuration for the specified fleet, which tells GameLift how to launch server processes on all instances in the fleet. You can update a fleet's runtime configuration at any time after the fleet is created; it does not need to be in ACTIVE status. To update runtime configuration, specify the fleet ID and provide a RuntimeConfiguration with an updated set of server process configurations. If successful, the fleet's runtime configuration settings are updated. Each instance in the fleet regularly checks for and retrieves updated runtime configurations. Instances immediately begin complying with the new configuration by launching new server processes or not replacing existing processes when they shut down. Updating a fleet's runtime configuration never affects existing server processes.  Learn more   Setting up GameLift fleets   Related actions   CreateFleetLocations | UpdateFleetAttributes | UpdateFleetCapacity | UpdateFleetPortSettings | UpdateRuntimeConfiguration | StopFleetActions | StartFleetActions | PutScalingPolicy | DeleteFleet | DeleteFleetLocations | DeleteScalingPolicy | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to update runtime configuration for. You can use either the fleet ID or ARN value.
        runtime_configuration(Dict): Instructions for launching server processes on each instance in the fleet. Server processes run either a custom game build executable or a Realtime Servers script. The runtime configuration lists the types of server processes to run on an instance, how to launch them, and the number of processes to run concurrently.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.runtime_configuration.update(
                ctx, fleet_id=value, runtime_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.runtime_configuration.update fleet_id=value, runtime_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_runtime_configuration",
        op_kwargs={"FleetId": fleet_id, "RuntimeConfiguration": runtime_configuration},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def send(hub, ctx, instance_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Sends a diagnostic interrupt to the specified Amazon EC2 instance to trigger a kernel panic (on Linux instances), or a blue screen/stop error (on Windows instances). For instances based on Intel and AMD processors, the interrupt is received as a non-maskable interrupt (NMI). In general, the operating system crashes and reboots when a kernel panic or stop error is triggered. The operating system can also be configured to perform diagnostic tasks, such as generating a memory dump file, loading a secondary kernel, or obtaining a call trace. Before sending a diagnostic interrupt to your instance, ensure that its operating system is configured to perform the required diagnostic tasks. For more information about configuring your operating system to generate a crash dump when a kernel panic or stop error occurs, see Send a diagnostic interrupt (Linux instances) or Send a Diagnostic Interrupt (Windows instances).

    Args:
        instance_id(str): The ID of the instance.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.diagnostic_interrupt.send(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.diagnostic_interrupt.send instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="send_diagnostic_interrupt",
        op_kwargs={"InstanceId": instance_id, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    load_balancer_name: str,
    listeners: List,
    availability_zones: List = None,
    subnets: List = None,
    security_groups: List = None,
    scheme: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Classic Load Balancer. You can add listeners, security groups, subnets, and tags when you create your load balancer, or you can add them later using CreateLoadBalancerListeners, ApplySecurityGroupsToLoadBalancer, AttachLoadBalancerToSubnets, and AddTags. To describe your current load balancers, see DescribeLoadBalancers. When you are finished with a load balancer, you can delete it using DeleteLoadBalancer. You can create up to 20 load balancers per region per account. You can request an increase for the number of load balancers for your account. For more information, see Limits for Your Classic Load Balancer in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer. This name must be unique within your set of load balancers for the region, must have a maximum of 32 characters, must contain only alphanumeric characters or hyphens, and cannot begin or end with a hyphen.
        listeners(List): The listeners. For more information, see Listeners for Your Classic Load Balancer in the Classic Load Balancers Guide.
        availability_zones(List, optional): One or more Availability Zones from the same region as the load balancer. You must specify at least one Availability Zone. You can add more Availability Zones after you create the load balancer using EnableAvailabilityZonesForLoadBalancer. Defaults to None.
        subnets(List, optional): The IDs of the subnets in your VPC to attach to the load balancer. Specify one subnet per Availability Zone specified in AvailabilityZones. Defaults to None.
        security_groups(List, optional): The IDs of the security groups to assign to the load balancer. Defaults to None.
        scheme(str, optional): The type of a load balancer. Valid only for load balancers in a VPC. By default, Elastic Load Balancing creates an Internet-facing load balancer with a DNS name that resolves to public IP addresses. For more information about Internet-facing and Internal load balancers, see Load Balancer Scheme in the Elastic Load Balancing User Guide. Specify internal to create a load balancer with a DNS name that resolves to private IP addresses. Defaults to None.
        tags(List, optional): A list of tags to assign to the load balancer. For more information about tagging your load balancer, see Tag Your Classic Load Balancer in the Classic Load Balancers Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.init.create(
                ctx, load_balancer_name=value, listeners=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.init.create load_balancer_name=value, listeners=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="create_load_balancer",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "Listeners": listeners,
            "AvailabilityZones": availability_zones,
            "Subnets": subnets,
            "SecurityGroups": security_groups,
            "Scheme": scheme,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, load_balancer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified load balancer. If you are attempting to recreate a load balancer, you must reconfigure all settings. The DNS name associated with a deleted load balancer are no longer usable. The name and associated DNS record of the deleted load balancer no longer exist and traffic sent to any of its IP addresses is no longer delivered to your instances. If the load balancer does not exist or has already been deleted, the call to DeleteLoadBalancer still succeeds.

    Args:
        load_balancer_name(str): The name of the load balancer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.init.delete(ctx, load_balancer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.init.delete load_balancer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="delete_load_balancer",
        op_kwargs={"LoadBalancerName": load_balancer_name},
    )


async def describe_all(
    hub,
    ctx,
    load_balancer_names: List = None,
    marker: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified the load balancers. If no load balancers are specified, the call describes all of your load balancers.

    Args:
        load_balancer_names(List, optional): The names of the load balancers. Defaults to None.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        page_size(int, optional): The maximum number of results to return with this call (a number from 1 to 400). The default is 400. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="describe_load_balancers",
        op_kwargs={
            "LoadBalancerNames": load_balancer_names,
            "Marker": marker,
            "PageSize": page_size,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    campaign_arn: str,
    item_id: str = None,
    user_id: str = None,
    num_results: int = None,
    context: Dict = None,
    filter_arn: str = None,
    filter_values: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of recommended items. The required input depends on the recipe type used to create the solution backing the campaign, as follows:   RELATED_ITEMS - itemId required, userId not used   USER_PERSONALIZATION - itemId optional, userId required    Campaigns that are backed by a solution created using a recipe of type PERSONALIZED_RANKING use the API.

    Args:
        campaign_arn(str): The Amazon Resource Name (ARN) of the campaign to use for getting recommendations.
        item_id(str, optional): The item ID to provide recommendations for. Required for RELATED_ITEMS recipe type. Defaults to None.
        user_id(str, optional): The user ID to provide recommendations for. Required for USER_PERSONALIZATION recipe type. Defaults to None.
        num_results(int, optional): The number of results to return. The default is 25. The maximum is 500. Defaults to None.
        context(Dict, optional): The contextual metadata to use when getting recommendations. Contextual metadata includes any interaction information that might be relevant when getting a user's recommendations, such as the user's current location or device type. Defaults to None.
        filter_arn(str, optional): The ARN of the filter to apply to the returned recommendations. For more information, see Filtering Recommendations. When using this parameter, be sure the filter resource is ACTIVE. Defaults to None.
        filter_values(Dict, optional): The values to use when filtering recommendations. For each placeholder parameter in your filter expression, provide the parameter name (in matching case) as a key and the filter value(s) as the corresponding value. Separate multiple values for one parameter with a comma.  For filter expressions that use an INCLUDE element to include items, you must provide values for all parameters that are defined in the expression. For filters with expressions that use an EXCLUDE element to exclude items, you can omit the filter-values.In this case, Amazon Personalize doesn't use that portion of the expression to filter recommendations. For more information, see Filtering Recommendations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize_runtime.recommendation.get_all(
                ctx, campaign_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize_runtime.recommendation.get_all campaign_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize-runtime",
        operation="get_recommendations",
        op_kwargs={
            "campaignArn": campaign_arn,
            "itemId": item_id,
            "userId": user_id,
            "numResults": num_results,
            "context": context,
            "filterArn": filter_arn,
            "filterValues": filter_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get_all(hub, ctx, platform_application_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging). For more information, see Using Amazon SNS Mobile Push Notifications.

    Args:
        platform_application_arn(str): PlatformApplicationArn for GetPlatformApplicationAttributesInput.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.platform.application.attribute.get_all(
                ctx, platform_application_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.platform.application.attribute.get_all platform_application_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="get_platform_application_attributes",
        op_kwargs={"PlatformApplicationArn": platform_application_arn},
    )


async def set_(hub, ctx, platform_application_arn: str, attributes: Dict) -> None:
    r"""
    **Autogenerated function**

    Sets the attributes of the platform application object for the supported push notification services, such as APNS and GCM (Firebase Cloud Messaging). For more information, see Using Amazon SNS Mobile Push Notifications. For information on configuring attributes for message delivery status, see Using Amazon SNS Application Attributes for Message Delivery Status.

    Args:
        platform_application_arn(str): PlatformApplicationArn for SetPlatformApplicationAttributes action.
        attributes(Dict): A map of the platform application attributes. Attributes in this map include the following:    PlatformCredential – The credential received from the notification service. For APNS and APNS_SANDBOX, PlatformCredential is private key. For GCM (Firebase Cloud Messaging), PlatformCredential is API key. For ADM, PlatformCredential is client secret.    PlatformPrincipal – The principal received from the notification service. For APNS and APNS_SANDBOX, PlatformPrincipal is SSL certificate. For GCM (Firebase Cloud Messaging), there is no PlatformPrincipal. For ADM, PlatformPrincipal is client id.    EventEndpointCreated – Topic ARN to which EndpointCreated event notifications are sent.    EventEndpointDeleted – Topic ARN to which EndpointDeleted event notifications are sent.    EventEndpointUpdated – Topic ARN to which EndpointUpdate event notifications are sent.    EventDeliveryFailure – Topic ARN to which DeliveryFailure event notifications are sent upon Direct Publish delivery failure (permanent) to one of the application's endpoints.    SuccessFeedbackRoleArn – IAM role ARN used to give Amazon SNS write access to use CloudWatch Logs on your behalf.    FailureFeedbackRoleArn – IAM role ARN used to give Amazon SNS write access to use CloudWatch Logs on your behalf.    SuccessFeedbackSampleRate – Sample rate percentage (0-100) of successfully delivered messages.  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.platform.application.attribute.set(
                ctx, platform_application_arn=value, attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.platform.application.attribute.set platform_application_arn=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="set_platform_application_attributes",
        op_kwargs={
            "PlatformApplicationArn": platform_application_arn,
            "Attributes": attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, organization_id: str, ip_address: str, action: str, user_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the effects of an organization's access control rules as they apply to a specified IPv4 address, access protocol action, or user ID.

    Args:
        organization_id(str): The identifier for the organization.
        ip_address(str): The IPv4 address.
        action(str): The access protocol action. Valid values include ActiveSync, AutoDiscover, EWS, IMAP, SMTP, WindowsOutlook, and WebMail.
        user_id(str): The user ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.access_control.effect.get(
                ctx, organization_id=value, ip_address=value, action=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.access_control.effect.get organization_id=value, ip_address=value, action=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="get_access_control_effect",
        op_kwargs={
            "OrganizationId": organization_id,
            "IpAddress": ip_address,
            "Action": action,
            "UserId": user_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "list"


async def create(
    hub, ctx, creator_request_id: str, name: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an empty firewall domain list for use in DNS Firewall rules. You can populate the domains for the new list with a file, using ImportFirewallDomains, or with domain strings, using UpdateFirewallDomains.

    Args:
        creator_request_id(str): A unique string that identifies the request and that allows you to retry failed requests without the risk of running the operation twice. CreatorRequestId can be any unique string, for example, a date/time stamp. .
        name(str): A name that lets you identify the domain list to manage and use it.
        tags(List, optional): A list of the tag keys and values that you want to associate with the domain list. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.domain.list_.create(
                ctx, creator_request_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.domain.list.create creator_request_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="create_firewall_domain_list",
        op_kwargs={"CreatorRequestId": creator_request_id, "Name": name, "Tags": tags},
    )


async def delete(hub, ctx, firewall_domain_list_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified domain list.

    Args:
        firewall_domain_list_id(str): The ID of the domain list that you want to delete. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.domain.list_.delete(
                ctx, firewall_domain_list_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.domain.list.delete firewall_domain_list_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="delete_firewall_domain_list",
        op_kwargs={"FirewallDomainListId": firewall_domain_list_id},
    )


async def get(hub, ctx, firewall_domain_list_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the specified firewall domain list.

    Args:
        firewall_domain_list_id(str): The ID of the domain list. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.domain.list_.get(
                ctx, firewall_domain_list_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.domain.list.get firewall_domain_list_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_firewall_domain_list",
        op_kwargs={"FirewallDomainListId": firewall_domain_list_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the firewall domain lists that you have defined. For each firewall domain list, you can retrieve the domains that are defined for a list by calling ListFirewallDomains.  A single call to this list operation might return only a partial list of the domain lists. For information, see MaxResults.

    Args:
        max_results(int, optional): The maximum number of objects that you want Resolver to return for this request. If more objects are available, in the response, Resolver provides a NextToken value that you can use in a subsequent call to get the next batch of objects. If you don't specify a value for MaxResults, Resolver returns up to 100 objects. . Defaults to None.
        next_token(str, optional): For the first call to this list request, omit this value. When you request a list of objects, Resolver returns at most the number of objects specified in MaxResults. If more objects are available for retrieval, Resolver returns a NextToken value in the response. To retrieve the next batch of objects, use the token that was returned for the prior request in your next request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.firewall.domain.list_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.firewall.domain.list.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_firewall_domain_lists",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub, ctx, certificate_arn: str = None, role_arn: str = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associates an Identity and Access Management (IAM) role with an Certificate Manager (ACM) certificate. This enables the certificate to be used by the ACM for Nitro Enclaves application inside an enclave. For more information, see Certificate Manager for Nitro Enclaves in the Amazon Web Services Nitro Enclaves User Guide. When the IAM role is associated with the ACM certificate, the certificate, certificate chain, and encrypted private key are placed in an Amazon S3 bucket that only the associated IAM role can access. The private key of the certificate is encrypted with an Amazon Web Services managed key that has an attached attestation-based key policy. To enable the IAM role to access the Amazon S3 object, you must grant it permission to call s3:GetObject on the Amazon S3 bucket returned by the command. To enable the IAM role to access the KMS key, you must grant it permission to call kms:Decrypt on the KMS key returned by the command. For more information, see  Grant the role permission to access the certificate and encryption key in the Amazon Web Services Nitro Enclaves User Guide.

    Args:
        certificate_arn(str, optional): The ARN of the ACM certificate with which to associate the IAM role. Defaults to None.
        role_arn(str, optional): The ARN of the IAM role to associate with the ACM certificate. You can associate up to 16 IAM roles with an ACM certificate. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.enclave_certificate_iam_role.associate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.enclave_certificate_iam_role.associate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="associate_enclave_certificate_iam_role",
        op_kwargs={
            "CertificateArn": certificate_arn,
            "RoleArn": role_arn,
            "DryRun": dry_run,
        },
    )


async def disassociate(
    hub, ctx, certificate_arn: str = None, role_arn: str = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates an IAM role from an Certificate Manager (ACM) certificate. Disassociating an IAM role from an ACM certificate removes the Amazon S3 object that contains the certificate, certificate chain, and encrypted private key from the Amazon S3 bucket. It also revokes the IAM role's permission to use the KMS key used to encrypt the private key. This effectively revokes the role's permission to use the certificate.

    Args:
        certificate_arn(str, optional): The ARN of the ACM certificate from which to disassociate the IAM role. Defaults to None.
        role_arn(str, optional): The ARN of the IAM role to disassociate. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.enclave_certificate_iam_role.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.enclave_certificate_iam_role.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disassociate_enclave_certificate_iam_role",
        op_kwargs={
            "CertificateArn": certificate_arn,
            "RoleArn": role_arn,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(
    hub, ctx, features: List, room_arn: str = None, device_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Resets a device and its account to the known default settings. This clears all information and settings set by previous users in the following ways:   Bluetooth - This unpairs all bluetooth devices paired with your echo device.   Volume - This resets the echo device's volume to the default value.   Notifications - This clears all notifications from your echo device.   Lists - This clears all to-do items from your echo device.   Settings - This internally syncs the room's profile (if the device is assigned to a room), contacts, address books, delegation access for account linking, and communications (if enabled on the room profile).

    Args:
        room_arn(str, optional): The ARN of the room with which the device to sync is associated. Required. Defaults to None.
        device_arn(str, optional): The ARN of the device to sync. Required. Defaults to None.
        features(List): Request structure to start the device sync. Required.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.device.sync.start(ctx, features=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.device.sync.start features=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="start_device_sync",
        op_kwargs={"RoomArn": room_arn, "DeviceArn": device_arn, "Features": features},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    disk_snapshot_name: str,
    disk_name: str = None,
    instance_name: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a snapshot of a block storage disk. You can use snapshots for backups, to make copies of disks, and to save data before shutting down a Lightsail instance. You can take a snapshot of an attached disk that is in use; however, snapshots only capture data that has been written to your disk at the time the snapshot command is issued. This may exclude any data that has been cached by any applications or the operating system. If you can pause any file systems on the disk long enough to take a snapshot, your snapshot should be complete. Nevertheless, if you cannot pause all file writes to the disk, you should unmount the disk from within the Lightsail instance, issue the create disk snapshot command, and then remount the disk to ensure a consistent and complete snapshot. You may remount and use your disk while the snapshot status is pending. You can also use this operation to create a snapshot of an instance's system volume. You might want to do this, for example, to recover data from the system volume of a botched instance or to create a backup of the system volume like you would for a block storage disk. To create a snapshot of a system volume, just define the instance name parameter when issuing the snapshot command, and a snapshot of the defined instance's system volume will be created. After the snapshot is available, you can create a block storage disk from the snapshot and attach it to a running instance to access the data on the disk. The create disk snapshot operation supports tag-based access control via request tags. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        disk_name(str, optional): The unique name of the source disk (e.g., Disk-Virginia-1).  This parameter cannot be defined together with the instance name parameter. The disk name and instance name parameters are mutually exclusive. . Defaults to None.
        disk_snapshot_name(str): The name of the destination disk snapshot (e.g., my-disk-snapshot) based on the source disk.
        instance_name(str, optional): The unique name of the source instance (e.g., Amazon_Linux-512MB-Virginia-1). When this is defined, a snapshot of the instance's system volume is created.  This parameter cannot be defined together with the disk name parameter. The instance name and disk name parameters are mutually exclusive. . Defaults to None.
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.snapshot.create(ctx, disk_snapshot_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.snapshot.create disk_snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_disk_snapshot",
        op_kwargs={
            "diskName": disk_name,
            "diskSnapshotName": disk_snapshot_name,
            "instanceName": instance_name,
            "tags": tags,
        },
    )


async def delete(hub, ctx, disk_snapshot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified disk snapshot. When you make periodic snapshots of a disk, the snapshots are incremental, and only the blocks on the device that have changed since your last snapshot are saved in the new snapshot. When you delete a snapshot, only the data not needed for any other snapshot is removed. So regardless of which prior snapshots have been deleted, all active snapshots will have access to all the information needed to restore the disk. The delete disk snapshot operation supports tag-based access control via resource tags applied to the resource identified by disk snapshot name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        disk_snapshot_name(str): The name of the disk snapshot you want to delete (e.g., my-disk-snapshot).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.snapshot.delete(ctx, disk_snapshot_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.snapshot.delete disk_snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_disk_snapshot",
        op_kwargs={"diskSnapshotName": disk_snapshot_name},
    )


async def get(hub, ctx, disk_snapshot_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific block storage disk snapshot.

    Args:
        disk_snapshot_name(str): The name of the disk snapshot (e.g., my-disk-snapshot).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.snapshot.get(ctx, disk_snapshot_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.snapshot.get disk_snapshot_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_disk_snapshot",
        op_kwargs={"diskSnapshotName": disk_snapshot_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all block storage disk snapshots in your AWS account and region.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetDiskSnapshots request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.disk.snapshot.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.disk.snapshot.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_disk_snapshots",
        op_kwargs={"pageToken": page_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, channel_name: str, messages: List) -> Dict:
    r"""
    **Autogenerated function**

    Sends messages to a channel.

    Args:
        channel_name(str): The name of the channel where the messages are sent.
        messages(List): The list of messages to be sent. Each message has the format: { "messageId": "string", "payload": "string"}. The field names of message payloads (data) that you send to IoT Analytics:   Must contain only alphanumeric characters and undescores (_). No other special characters are allowed.   Must begin with an alphabetic character or single underscore (_).   Cannot contain hyphens (-).   In regular expression terms: "^[A-Za-z_]([A-Za-z0-9]*|[A-Za-z0-9][A-Za-z0-9_]*)$".    Cannot be more than 255 characters.   Are case insensitive. (Fields named foo and FOO in the same payload are considered duplicates.)   For example, {"temp_01": 29} or {"_temp_01": 29} are valid, but {"temp-01": 29}, {"01_temp": 29} or {"__temp_01": 29} are invalid in message payloads. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.put_message.batch(
                ctx, channel_name=value, messages=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.put_message.batch channel_name=value, messages=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="batch_put_message",
        op_kwargs={"channelName": channel_name, "messages": messages},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    association_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes your IAM instance profile associations.

    Args:
        association_ids(List, optional): The IAM instance profile associations. Defaults to None.
        filters(List, optional): The filters.    instance-id - The ID of the instance.    state - The state of the association (associating | associated | disassociating).  . Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.iam_instance_profile.association.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.iam_instance_profile.association.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_iam_instance_profile_associations",
        op_kwargs={
            "AssociationIds": association_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def replace(hub, ctx, iam_instance_profile: Dict, association_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Replaces an IAM instance profile for the specified running instance. You can use this action to change the IAM instance profile that's associated with an instance without having to disassociate the existing IAM instance profile first. Use DescribeIamInstanceProfileAssociations to get the association ID.

    Args:
        iam_instance_profile(Dict): The IAM instance profile.
        association_id(str): The ID of the existing IAM instance profile association.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.iam_instance_profile.association.replace(
                ctx, iam_instance_profile=value, association_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.iam_instance_profile.association.replace iam_instance_profile=value, association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="replace_iam_instance_profile_association",
        op_kwargs={
            "IamInstanceProfile": iam_instance_profile,
            "AssociationId": association_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, bundle_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a bundling operation for an instance store-backed Windows instance.

    Args:
        bundle_id(str): The ID of the bundle task.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.bundle_task.cancel(ctx, bundle_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.bundle_task.cancel bundle_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="cancel_bundle_task",
        op_kwargs={"BundleId": bundle_id, "DryRun": dry_run},
    )


async def describe_all(
    hub, ctx, bundle_ids: List = None, filters: List = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified bundle tasks or all of your bundle tasks.  Completed bundle tasks are listed for only a limited time. If your bundle task is no longer in the list, you can still register an AMI from it. Just use RegisterImage with the Amazon S3 bucket name and image manifest name you provided to the bundle task.

    Args:
        bundle_ids(List, optional): The bundle task IDs. Default: Describes all your bundle tasks. Defaults to None.
        filters(List, optional): The filters.    bundle-id - The ID of the bundle task.    error-code - If the task failed, the error code returned.    error-message - If the task failed, the error message returned.    instance-id - The ID of the instance.    progress - The level of task completion, as a percentage (for example, 20%).    s3-bucket - The Amazon S3 bucket to store the AMI.    s3-prefix - The beginning of the AMI name.    start-time - The time the task started (for example, 2013-09-15T17:15:20.000Z).    state - The state of the task (pending | waiting-for-shutdown | bundling | storing | cancelling | complete | failed).    update-time - The time of the most recent update for the task.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.bundle_task.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.bundle_task.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_bundle_tasks",
        op_kwargs={"BundleIds": bundle_ids, "Filters": filters, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, filters: List = None, dry_run: bool = None, vpc_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the ClassicLink status of one or more VPCs.

    Args:
        filters(List, optional): One or more filters.    is-classic-link-enabled - Whether the VPC is enabled for ClassicLink (true | false).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        vpc_ids(List, optional): One or more VPCs for which you want to describe the ClassicLink status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.classic_link.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.classic_link.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpc_classic_link",
        op_kwargs={"Filters": filters, "DryRun": dry_run, "VpcIds": vpc_ids},
    )


async def disable(hub, ctx, vpc_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Disables ClassicLink for a VPC. You cannot disable ClassicLink for a VPC that has EC2-Classic instances linked to it.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        vpc_id(str): The ID of the VPC.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.classic_link.init.disable(ctx, vpc_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.classic_link.init.disable vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disable_vpc_classic_link",
        op_kwargs={"DryRun": dry_run, "VpcId": vpc_id},
    )


async def enable(hub, ctx, vpc_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Enables a VPC for ClassicLink. You can then link EC2-Classic instances to your ClassicLink-enabled VPC to allow communication over private IP addresses. You cannot enable your VPC for ClassicLink if any of your VPC route tables have existing routes for address ranges within the 10.0.0.0/8 IP address range, excluding local routes for VPCs in the 10.0.0.0/16 and 10.1.0.0/16 IP address ranges. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        vpc_id(str): The ID of the VPC.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.classic_link.init.enable(ctx, vpc_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.classic_link.init.enable vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="enable_vpc_classic_link",
        op_kwargs={"DryRun": dry_run, "VpcId": vpc_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    document_id: str,
    version_id: str,
    text: str,
    authentication_token: str = None,
    parent_id: str = None,
    thread_id: str = None,
    visibility: str = None,
    notify_collaborators: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a new comment to the specified document version.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        document_id(str): The ID of the document.
        version_id(str): The ID of the document version.
        parent_id(str, optional): The ID of the parent comment. Defaults to None.
        thread_id(str, optional): The ID of the root comment in the thread. Defaults to None.
        text(str): The text of the comment.
        visibility(str, optional): The visibility of the comment. Options are either PRIVATE, where the comment is visible only to the comment author and document owner and co-owners, or PUBLIC, where the comment is visible to document owners, co-owners, and contributors. Defaults to None.
        notify_collaborators(bool, optional): Set this parameter to TRUE to send an email out to the document collaborators after the comment is created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.comment.create(
                ctx, document_id=value, version_id=value, text=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.comment.create document_id=value, version_id=value, text=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="create_comment",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "DocumentId": document_id,
            "VersionId": version_id,
            "ParentId": parent_id,
            "ThreadId": thread_id,
            "Text": text,
            "Visibility": visibility,
            "NotifyCollaborators": notify_collaborators,
        },
    )


async def delete(
    hub,
    ctx,
    document_id: str,
    version_id: str,
    comment_id: str,
    authentication_token: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified comment from the document version.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        document_id(str): The ID of the document.
        version_id(str): The ID of the document version.
        comment_id(str): The ID of the comment.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.comment.delete(
                ctx, document_id=value, version_id=value, comment_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.comment.delete document_id=value, version_id=value, comment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="delete_comment",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "DocumentId": document_id,
            "VersionId": version_id,
            "CommentId": comment_id,
        },
    )


async def describe_all(
    hub,
    ctx,
    document_id: str,
    version_id: str,
    authentication_token: str = None,
    limit: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List all the comments for the specified document version.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        document_id(str): The ID of the document.
        version_id(str): The ID of the document version.
        limit(int, optional): The maximum number of items to return. Defaults to None.
        marker(str, optional): The marker for the next set of results. This marker was received from a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.comment.describe_all(
                ctx, document_id=value, version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.comment.describe_all document_id=value, version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="describe_comments",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "DocumentId": document_id,
            "VersionId": version_id,
            "Limit": limit,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    alert_name: str,
    alert_sensitivity_threshold: int,
    anomaly_detector_arn: str,
    action: Dict,
    alert_description: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an alert for an anomaly detector.

    Args:
        alert_name(str): The name of the alert.
        alert_sensitivity_threshold(int): An integer from 0 to 100 specifying the alert sensitivity threshold.
        alert_description(str, optional): A description of the alert. Defaults to None.
        anomaly_detector_arn(str): The ARN of the detector to which the alert is attached.
        action(Dict): Action that will be triggered when there is an alert.
        tags(Dict, optional): A list of tags to apply to the alert. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.alert.create(
                ctx,
                alert_name=value,
                alert_sensitivity_threshold=value,
                anomaly_detector_arn=value,
                action=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.alert.create alert_name=value, alert_sensitivity_threshold=value, anomaly_detector_arn=value, action=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="create_alert",
        op_kwargs={
            "AlertName": alert_name,
            "AlertSensitivityThreshold": alert_sensitivity_threshold,
            "AlertDescription": alert_description,
            "AnomalyDetectorArn": anomaly_detector_arn,
            "Action": action,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, alert_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an alert.

    Args:
        alert_arn(str): The ARN of the alert to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.alert.delete(ctx, alert_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.alert.delete alert_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="delete_alert",
        op_kwargs={"AlertArn": alert_arn},
    )


async def describe(hub, ctx, alert_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an alert. Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.

    Args:
        alert_arn(str): The ARN of the alert to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.alert.describe(ctx, alert_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.alert.describe alert_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="describe_alert",
        op_kwargs={"AlertArn": alert_arn},
    )


async def list_all(
    hub,
    ctx,
    anomaly_detector_arn: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the alerts attached to a detector. Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.

    Args:
        anomaly_detector_arn(str, optional): The ARN of the alert's detector. Defaults to None.
        next_token(str, optional): If the result of the previous request is truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request. Tokens expire after 24 hours. Defaults to None.
        max_results(int, optional): The maximum number of results that will be displayed by the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.alert.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.alert.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="list_alerts",
        op_kwargs={
            "AnomalyDetectorArn": anomaly_detector_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    savings_plan_offering_id: str,
    commitment: str,
    upfront_payment_amount: str = None,
    purchase_time: str = None,
    client_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Savings Plan.

    Args:
        savings_plan_offering_id(str): The ID of the offering.
        commitment(str): The hourly commitment, in USD. This is a value between 0.001 and 1 million. You cannot specify more than three digits after the decimal point.
        upfront_payment_amount(str, optional): The up-front payment amount. This is a whole number between 50 and 99 percent of the total value of the Savings Plan. This parameter is supported only if the payment option is Partial Upfront. Defaults to None.
        purchase_time(str, optional): The time at which to purchase the Savings Plan, in UTC format (YYYY-MM-DDTHH:MM:SSZ). Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        tags(Dict, optional): One or more tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.savingsplan.saving_plan.init.create(
                ctx, savings_plan_offering_id=value, commitment=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.savingsplan.saving_plan.init.create savings_plan_offering_id=value, commitment=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="savingsplans",
        operation="create_savings_plan",
        op_kwargs={
            "savingsPlanOfferingId": savings_plan_offering_id,
            "commitment": commitment,
            "upfrontPaymentAmount": upfront_payment_amount,
            "purchaseTime": purchase_time,
            "clientToken": client_token,
            "tags": tags,
        },
    )


async def describe_all(
    hub,
    ctx,
    savings_plan_arns: List = None,
    savings_plan_ids: List = None,
    next_token: str = None,
    max_results: int = None,
    states: List = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified Savings Plans.

    Args:
        savings_plan_arns(List, optional): The Amazon Resource Names (ARN) of the Savings Plans. Defaults to None.
        savings_plan_ids(List, optional): The IDs of the Savings Plans. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve additional results, make another call with the returned token value. Defaults to None.
        states(List, optional): The states. Defaults to None.
        filters(List, optional): The filters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.savingsplan.saving_plan.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.savingsplan.saving_plan.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="savingsplans",
        operation="describe_savings_plans",
        op_kwargs={
            "savingsPlanArns": savings_plan_arns,
            "savingsPlanIds": savings_plan_ids,
            "nextToken": next_token,
            "maxResults": max_results,
            "states": states,
            "filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    hit_type_id: str = None,
    status: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The ListReviewableHITs operation retrieves the HITs with Status equal to Reviewable or Status equal to Reviewing that belong to the Requester calling the operation.

    Args:
        hit_type_id(str, optional):  The ID of the HIT type of the HITs to consider for the query. If not specified, all HITs for the Reviewer are considered . Defaults to None.
        status(str, optional):  Can be either Reviewable or Reviewing. Reviewable is the default value. . Defaults to None.
        next_token(str, optional): Pagination Token. Defaults to None.
        max_results(int, optional):  Limit the number of results returned. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.reviewable_hit.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.reviewable_hit.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="list_reviewable_hits",
        op_kwargs={
            "HITTypeId": hit_type_id,
            "Status": status,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub, ctx, secret_id: str, version_id: str = None, version_stage: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the contents of the encrypted fields SecretString or SecretBinary from the specified version of a secret, whichever contains content.  Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:GetSecretValue   kms:Decrypt - required only if you use a customer-managed Amazon Web Services KMS key to encrypt the secret. You do not need this permission to use the account's default Amazon Web Services managed CMK for Secrets Manager.    Related operations    To create a new version of the secret with different encrypted information, use PutSecretValue.   To retrieve the non-encrypted details for the secret, use DescribeSecret.

    Args:
        secret_id(str): Specifies the secret containing the version that you want to retrieve. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .
        version_id(str, optional): Specifies the unique identifier of the version of the secret that you want to retrieve. If you specify both this parameter and VersionStage, the two parameters must refer to the same secret version. If you don't specify either a VersionStage or VersionId then the default is to perform the operation on the version with the VersionStage value of AWSCURRENT. This value is typically a UUID-type value with 32 hexadecimal digits. Defaults to None.
        version_stage(str, optional): Specifies the secret version that you want to retrieve by the staging label attached to the version. Staging labels are used to keep track of different versions during the rotation process. If you specify both this parameter and VersionId, the two parameters must refer to the same secret version . If you don't specify either a VersionStage or VersionId, then the default is to perform the operation on the version with the VersionStage value of AWSCURRENT. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.secret.value.get(ctx, secret_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.secret.value.get secret_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="get_secret_value",
        op_kwargs={
            "SecretId": secret_id,
            "VersionId": version_id,
            "VersionStage": version_stage,
        },
    )


async def put(
    hub,
    ctx,
    secret_id: str,
    client_request_token: str = None,
    secret_binary: bytes = None,
    secret_string: str = None,
    version_stages: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Stores a new encrypted secret value in the specified secret. To do this, the operation creates a new version and attaches it to the secret. The version can contain a new SecretString value or a new SecretBinary value. You can also specify the staging labels that are initially attached to the new version.  The Secrets Manager console uses only the SecretString field. To add binary data to a secret with the SecretBinary field you must use the Amazon Web Services CLI or one of the Amazon Web Services SDKs.    If this operation creates the first version for the secret then Secrets Manager automatically attaches the staging label AWSCURRENT to the new version.   If you do not specify a value for VersionStages then Secrets Manager automatically moves the staging label AWSCURRENT to this new version.   If this operation moves the staging label AWSCURRENT from another version to this version, then Secrets Manager also automatically moves the staging label AWSPREVIOUS to the version that AWSCURRENT was removed from.   This operation is idempotent. If a version with a VersionId with the same value as the ClientRequestToken parameter already exists and you specify the same secret data, the operation succeeds but does nothing. However, if the secret data is different, then the operation fails because you cannot modify an existing version; you can only create new ones.      If you call an operation to encrypt or decrypt the SecretString or SecretBinary for a secret in the same account as the calling user and that secret doesn't specify a Amazon Web Services KMS encryption key, Secrets Manager uses the account's default Amazon Web Services managed customer master key (CMK) with the alias aws/secretsmanager. If this key doesn't already exist in your account then Secrets Manager creates it for you automatically. All users and roles in the same Amazon Web Services account automatically have access to use the default CMK. Note that if an Secrets Manager API call results in Amazon Web Services creating the account's Amazon Web Services-managed CMK, it can result in a one-time significant delay in returning the result.   If the secret resides in a different Amazon Web Services account from the credentials calling an API that requires encryption or decryption of the secret value then you must create and use a custom Amazon Web Services KMS CMK because you can't access the default CMK for the account using credentials from a different Amazon Web Services account. Store the ARN of the CMK in the secret when you create the secret or when you update it by including it in the KMSKeyId. If you call an API that must encrypt or decrypt SecretString or SecretBinary using credentials from a different account then the Amazon Web Services KMS key policy must grant cross-account access to that other account's user or role for both the kms:GenerateDataKey and kms:Decrypt operations.     Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:PutSecretValue   kms:GenerateDataKey - needed only if you use a customer-managed Amazon Web Services KMS key to encrypt the secret. You do not need this permission to use the account's default Amazon Web Services managed CMK for Secrets Manager.    Related operations    To retrieve the encrypted value you store in the version of a secret, use GetSecretValue.   To create a secret, use CreateSecret.   To get the details for a secret, use DescribeSecret.   To list the versions attached to a secret, use ListSecretVersionIds.

    Args:
        secret_id(str): Specifies the secret to which you want to add a new version. You can specify either the Amazon Resource Name (ARN) or the friendly name of the secret. The secret must already exist.  If you specify an ARN, we generally recommend that you specify a complete ARN. You can specify a partial ARN too—for example, if you don’t include the final hyphen and six random characters that Secrets Manager adds at the end of the ARN when you created the secret. A partial ARN match can work as long as it uniquely matches only one secret. However, if your secret has a name that ends in a hyphen followed by six characters (before Secrets Manager adds the hyphen and six characters to the ARN) and you try to use that as a partial ARN, then those characters cause Secrets Manager to assume that you’re specifying a complete ARN. This confusion can cause unexpected results. To avoid this situation, we recommend that you don’t create secret names ending with a hyphen followed by six characters. If you specify an incomplete ARN without the random suffix, and instead provide the 'friendly name', you must not include the random suffix. If you do include the random suffix added by Secrets Manager, you receive either a ResourceNotFoundException or an AccessDeniedException error, depending on your permissions. .
        client_request_token(str, optional): (Optional) Specifies a unique identifier for the new version of the secret.   If you use the Amazon Web Services CLI or one of the Amazon Web Services SDK to call this operation, then you can leave this parameter empty. The CLI or SDK generates a random UUID for you and includes that in the request. If you don't use the SDK and instead generate a raw HTTP request to the Secrets Manager service endpoint, then you must generate a ClientRequestToken yourself for new versions and include that value in the request.   This value helps ensure idempotency. Secrets Manager uses this value to prevent the accidental creation of duplicate versions if there are failures and retries during the Lambda rotation function's processing. We recommend that you generate a UUID-type value to ensure uniqueness within the specified secret.    If the ClientRequestToken value isn't already associated with a version of the secret then a new version of the secret is created.    If a version with this value already exists and that version's SecretString or SecretBinary values are the same as those in the request then the request is ignored (the operation is idempotent).    If a version with this value already exists and the version of the SecretString and SecretBinary values are different from those in the request then the request fails because you cannot modify an existing secret version. You can only create new versions to store new secret values.   This value becomes the VersionId of the new version. Defaults to None.
        secret_binary(bytes, optional): (Optional) Specifies binary data that you want to encrypt and store in the new version of the secret. To use this parameter in the command-line tools, we recommend that you store your binary data in a file and then use the appropriate technique for your tool to pass the contents of the file as a parameter. Either SecretBinary or SecretString must have a value, but not both. They cannot both be empty. This parameter is not accessible if the secret using the Secrets Manager console. . Defaults to None.
        secret_string(str, optional): (Optional) Specifies text data that you want to encrypt and store in this new version of the secret. Either SecretString or SecretBinary must have a value, but not both. They cannot both be empty. If you create this secret by using the Secrets Manager console then Secrets Manager puts the protected secret text in only the SecretString parameter. The Secrets Manager console stores the information as a JSON structure of key/value pairs that the default Lambda rotation function knows how to parse. For storing multiple values, we recommend that you use a JSON text string argument and specify key/value pairs. For information on how to format a JSON parameter for the various command line tool environments, see Using JSON for Parameters in the CLI User Guide.  For example:  [{"username":"bob"},{"password":"abc123xyz456"}]  If your command-line tool or SDK requires quotation marks around the parameter, you should use single quotes to avoid confusion with the double quotes required in the JSON text. Defaults to None.
        version_stages(List, optional): (Optional) Specifies a list of staging labels that are attached to this version of the secret. These staging labels are used to track the versions through the rotation process by the Lambda rotation function. A staging label must be unique to a single version of the secret. If you specify a staging label that's already associated with a different version of the same secret then that staging label is automatically removed from the other version and attached to this version. If you do not specify a value for VersionStages then Secrets Manager automatically moves the staging label AWSCURRENT to this new version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.secret.value.put(ctx, secret_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.secret.value.put secret_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="put_secret_value",
        op_kwargs={
            "SecretId": secret_id,
            "ClientRequestToken": client_request_token,
            "SecretBinary": secret_binary,
            "SecretString": secret_string,
            "VersionStages": version_stages,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def resolve(hub, ctx, registration_token: str) -> Dict:
    r"""
    **Autogenerated function**

    ResolveCustomer is called by a SaaS application during the registration process. When a buyer visits your website during the registration process, the buyer submits a registration token through their browser. The registration token is resolved through this API to obtain a CustomerIdentifier and product code.

    Args:
        registration_token(str): When a buyer visits your website during the registration process, the buyer submits a registration token through the browser. The registration token is resolved to obtain a CustomerIdentifier and product code.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.meteringmarketplace.customer.resolve(
                ctx, registration_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.meteringmarketplace.customer.resolve registration_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="meteringmarketplace",
        operation="resolve_customer",
        op_kwargs={"RegistrationToken": registration_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    from_phone_number: str,
    to_phone_number: str,
    sip_media_application_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an outbound call to a phone number from the phone number specified in the request, and it invokes the endpoint of the specified sipMediaApplicationId.

    Args:
        from_phone_number(str): The phone number that a user calls from. This is a phone number in your Amazon Chime phone number inventory.
        to_phone_number(str): The phone number that the service should call.
        sip_media_application_id(str): The ID of the SIP media application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.media_application.call.create(
                ctx, from_phone_number=value, to_phone_number=value, sip_media_application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.media_application.call.create from_phone_number=value, to_phone_number=value, sip_media_application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_sip_media_application_call",
        op_kwargs={
            "FromPhoneNumber": from_phone_number,
            "ToPhoneNumber": to_phone_number,
            "SipMediaApplicationId": sip_media_application_id,
        },
    )


async def update(
    hub, ctx, sip_media_application_id: str, transaction_id: str, arguments: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Allows you to trigger a Lambda function at any time while a call is active, and replace the current actions with new actions returned by the invocation.

    Args:
        sip_media_application_id(str): The ID of the SIP media application handling the call.
        transaction_id(str): The ID of the call transaction.
        arguments(Dict): Arguments made available to the Lambda function as part of the CALL_UPDATE_REQUESTED event. Can contain 0-20 key-value pairs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.sip.media_application.call.update(
                ctx, sip_media_application_id=value, transaction_id=value, arguments=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.sip.media_application.call.update sip_media_application_id=value, transaction_id=value, arguments=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_sip_media_application_call",
        op_kwargs={
            "SipMediaApplicationId": sip_media_application_id,
            "TransactionId": transaction_id,
            "Arguments": arguments,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub,
    ctx,
    stack_set_name: str,
    regions: List,
    accounts: List = None,
    deployment_targets: Dict = None,
    parameter_overrides: List = None,
    operation_preferences: Dict = None,
    operation_id: str = None,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates stack instances for the specified accounts, within the specified Regions. A stack instance refers to a stack in a specific account and Region. You must specify at least one value for either Accounts or DeploymentTargets, and you must specify at least one value for Regions.

    Args:
        stack_set_name(str): The name or unique ID of the stack set that you want to create stack instances from.
        accounts(List, optional): [Self-managed permissions] The names of one or more accounts that you want to create stack instances in the specified Region(s) for. You can specify Accounts or DeploymentTargets, but not both. Defaults to None.
        deployment_targets(Dict, optional): [Service-managed permissions] The Organizations accounts for which to create stack instances in the specified Regions. You can specify Accounts or DeploymentTargets, but not both. Defaults to None.
        regions(List): The names of one or more Regions where you want to create stack instances using the specified accounts. .
        parameter_overrides(List, optional): A list of stack set parameters whose values you want to override in the selected stack instances. Any overridden parameter values will be applied to all stack instances in the specified accounts and Regions. When specifying parameters and their values, be aware of how CloudFormation sets parameter values during stack instance operations:   To override the current value for a parameter, include the parameter and specify its value.   To leave an overridden parameter set to its present value, include the parameter and specify UsePreviousValue as true. (You cannot specify both a value and set UsePreviousValue to true.)   To set an overridden parameter back to the value specified in the stack set, specify a parameter list but do not include the parameter in the list.   To leave all parameters set to their present values, do not specify this property at all.   During stack set updates, any parameter values overridden for a stack instance are not updated, but retain their overridden value. You can only override the parameter values that are specified in the stack set; to add or delete a parameter itself, use UpdateStackSet to update the stack set template. Defaults to None.
        operation_preferences(Dict, optional): Preferences for how CloudFormation performs this stack set operation. Defaults to None.
        operation_id(str, optional): The unique identifier for this stack set operation.  The operation ID also functions as an idempotency token, to ensure that CloudFormation performs the stack set operation only once, even if you retry the request multiple times. You might retry stack set operation requests to ensure that CloudFormation successfully received them. If you don't specify an operation ID, the SDK generates one automatically.  Repeating this stack set operation with a new operation ID retries all stack instances whose status is OUTDATED. . Defaults to None.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.instance.create_multiple(
                ctx, stack_set_name=value, regions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.instance.create_multiple stack_set_name=value, regions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="create_stack_instances",
        op_kwargs={
            "StackSetName": stack_set_name,
            "Accounts": accounts,
            "DeploymentTargets": deployment_targets,
            "Regions": regions,
            "ParameterOverrides": parameter_overrides,
            "OperationPreferences": operation_preferences,
            "OperationId": operation_id,
            "CallAs": call_as,
        },
    )


async def delete_multiple(
    hub,
    ctx,
    stack_set_name: str,
    regions: List,
    retain_stacks: bool,
    accounts: List = None,
    deployment_targets: Dict = None,
    operation_preferences: Dict = None,
    operation_id: str = None,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes stack instances for the specified accounts, in the specified Regions.

    Args:
        stack_set_name(str): The name or unique ID of the stack set that you want to delete stack instances for.
        accounts(List, optional): [Self-managed permissions] The names of the accounts that you want to delete stack instances for. You can specify Accounts or DeploymentTargets, but not both. Defaults to None.
        deployment_targets(Dict, optional): [Service-managed permissions] The Organizations accounts from which to delete stack instances. You can specify Accounts or DeploymentTargets, but not both. Defaults to None.
        regions(List): The Regions where you want to delete stack set instances. .
        operation_preferences(Dict, optional): Preferences for how CloudFormation performs this stack set operation. Defaults to None.
        retain_stacks(bool): Removes the stack instances from the specified stack set, but doesn't delete the stacks. You can't reassociate a retained stack or add an existing, saved stack to a new stack set. For more information, see Stack set operation options.
        operation_id(str, optional): The unique identifier for this stack set operation.  If you don't specify an operation ID, the SDK generates one automatically.  The operation ID also functions as an idempotency token, to ensure that CloudFormation performs the stack set operation only once, even if you retry the request multiple times. You can retry stack set operation requests to ensure that CloudFormation successfully received them. Repeating this stack set operation with a new operation ID retries all stack instances whose status is OUTDATED. . Defaults to None.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.instance.delete_multiple(
                ctx, stack_set_name=value, regions=value, retain_stacks=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.instance.delete_multiple stack_set_name=value, regions=value, retain_stacks=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="delete_stack_instances",
        op_kwargs={
            "StackSetName": stack_set_name,
            "Accounts": accounts,
            "DeploymentTargets": deployment_targets,
            "Regions": regions,
            "OperationPreferences": operation_preferences,
            "RetainStacks": retain_stacks,
            "OperationId": operation_id,
            "CallAs": call_as,
        },
    )


async def describe(
    hub,
    ctx,
    stack_set_name: str,
    stack_instance_account: str,
    stack_instance_region: str,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the stack instance that's associated with the specified stack set, account, and Region. For a list of stack instances that are associated with a specific stack set, use ListStackInstances.

    Args:
        stack_set_name(str): The name or the unique stack ID of the stack set that you want to get stack instance information for.
        stack_instance_account(str): The ID of an account that's associated with this stack instance.
        stack_instance_region(str): The name of a Region that's associated with this stack instance.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.instance.describe(
                ctx, stack_set_name=value, stack_instance_account=value, stack_instance_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.instance.describe stack_set_name=value, stack_instance_account=value, stack_instance_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="describe_stack_instance",
        op_kwargs={
            "StackSetName": stack_set_name,
            "StackInstanceAccount": stack_instance_account,
            "StackInstanceRegion": stack_instance_region,
            "CallAs": call_as,
        },
    )


async def list_all(
    hub,
    ctx,
    stack_set_name: str,
    next_token: str = None,
    max_results: int = None,
    filters: List = None,
    stack_instance_account: str = None,
    stack_instance_region: str = None,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns summary information about stack instances that are associated with the specified stack set. You can filter for stack instances that are associated with a specific account name or Region, or that have a specific status.

    Args:
        stack_set_name(str): The name or unique ID of the stack set that you want to list stack instances for.
        next_token(str, optional): If the previous request didn't return all of the remaining results, the response's NextToken parameter value is set to a token. To retrieve the next set of results, call ListStackInstances again and assign that token to the request object's NextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results. Defaults to None.
        filters(List, optional): The status that stack instances are filtered by. Defaults to None.
        stack_instance_account(str, optional): The name of the account that you want to list stack instances for. Defaults to None.
        stack_instance_region(str, optional): The name of the Region where you want to list stack instances. . Defaults to None.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.instance.list_all(
                ctx, stack_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.instance.list_all stack_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="list_stack_instances",
        op_kwargs={
            "StackSetName": stack_set_name,
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
            "StackInstanceAccount": stack_instance_account,
            "StackInstanceRegion": stack_instance_region,
            "CallAs": call_as,
        },
    )


async def update_multiple(
    hub,
    ctx,
    stack_set_name: str,
    regions: List,
    accounts: List = None,
    deployment_targets: Dict = None,
    parameter_overrides: List = None,
    operation_preferences: Dict = None,
    operation_id: str = None,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the parameter values for stack instances for the specified accounts, within the specified Regions. A stack instance refers to a stack in a specific account and Region.  You can only update stack instances in Regions and accounts where they already exist; to create additional stack instances, use CreateStackInstances.  During stack set updates, any parameters overridden for a stack instance are not updated, but retain their overridden value. You can only update the parameter values that are specified in the stack set; to add or delete a parameter itself, use UpdateStackSet to update the stack set template. If you add a parameter to a template, before you can override the parameter value specified in the stack set you must first use UpdateStackSet to update all stack instances with the updated template and parameter value specified in the stack set. Once a stack instance has been updated with the new parameter, you can then override the parameter value using UpdateStackInstances.

    Args:
        stack_set_name(str): The name or unique ID of the stack set associated with the stack instances.
        accounts(List, optional): [Self-managed permissions] The names of one or more accounts for which you want to update parameter values for stack instances. The overridden parameter values will be applied to all stack instances in the specified accounts and Regions. You can specify Accounts or DeploymentTargets, but not both. Defaults to None.
        deployment_targets(Dict, optional): [Service-managed permissions] The Organizations accounts for which you want to update parameter values for stack instances. If your update targets OUs, the overridden parameter values only apply to the accounts that are currently in the target OUs and their child OUs. Accounts added to the target OUs and their child OUs in the future won't use the overridden values. You can specify Accounts or DeploymentTargets, but not both. Defaults to None.
        regions(List): The names of one or more Regions in which you want to update parameter values for stack instances. The overridden parameter values will be applied to all stack instances in the specified accounts and Regions.
        parameter_overrides(List, optional):  A list of input parameters whose values you want to update for the specified stack instances.  Any overridden parameter values will be applied to all stack instances in the specified accounts and Regions. When specifying parameters and their values, be aware of how CloudFormation sets parameter values during stack instance update operations:   To override the current value for a parameter, include the parameter and specify its value.   To leave an overridden parameter set to its present value, include the parameter and specify UsePreviousValue as true. (You cannot specify both a value and set UsePreviousValue to true.)   To set an overridden parameter back to the value specified in the stack set, specify a parameter list but do not include the parameter in the list.   To leave all parameters set to their present values, do not specify this property at all.   During stack set updates, any parameter values overridden for a stack instance are not updated, but retain their overridden value. You can only override the parameter values that are specified in the stack set; to add or delete a parameter itself, use UpdateStackSet to update the stack set template. If you add a parameter to a template, before you can override the parameter value specified in the stack set you must first use UpdateStackSet to update all stack instances with the updated template and parameter value specified in the stack set. Once a stack instance has been updated with the new parameter, you can then override the parameter value using UpdateStackInstances. Defaults to None.
        operation_preferences(Dict, optional): Preferences for how CloudFormation performs this stack set operation. Defaults to None.
        operation_id(str, optional): The unique identifier for this stack set operation.  The operation ID also functions as an idempotency token, to ensure that CloudFormation performs the stack set operation only once, even if you retry the request multiple times. You might retry stack set operation requests to ensure that CloudFormation successfully received them. If you don't specify an operation ID, the SDK generates one automatically. . Defaults to None.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.instance.update_multiple(
                ctx, stack_set_name=value, regions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.instance.update_multiple stack_set_name=value, regions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="update_stack_instances",
        op_kwargs={
            "StackSetName": stack_set_name,
            "Accounts": accounts,
            "DeploymentTargets": deployment_targets,
            "Regions": regions,
            "ParameterOverrides": parameter_overrides,
            "OperationPreferences": operation_preferences,
            "OperationId": operation_id,
            "CallAs": call_as,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, event_source_name: str = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new event bus within your account. This can be a custom event bus which you can use to receive events from your custom applications and services, or it can be a partner event bus which can be matched to a partner event source.

    Args:
        name(str): The name of the new event bus.  Event bus names cannot contain the / character. You can't use the name default for a custom event bus, as this name is already used for your account's default event bus. If this is a partner event bus, the name must exactly match the name of the partner event source that this event bus is matched to.
        event_source_name(str, optional): If you are creating a partner event bus, this specifies the partner event source that the new event bus will be matched with. Defaults to None.
        tags(List, optional): Tags to associate with the event bus. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.bus.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.bus.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="create_event_bus",
        op_kwargs={"Name": name, "EventSourceName": event_source_name, "Tags": tags},
    )


async def delete(hub, ctx, name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified custom event bus or partner event bus. All rules associated with this event bus need to be deleted. You can't delete your account's default event bus.

    Args:
        name(str): The name of the event bus to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.bus.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.bus.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="delete_event_bus",
        op_kwargs={"Name": name},
    )


async def describe(hub, ctx, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Displays details about an event bus in your account. This can include the external AWS accounts that are permitted to write events to your default event bus, and the associated policy. For custom event buses and partner event buses, it displays the name, ARN, policy, state, and creation time.  To enable your account to receive events from other accounts on its default event bus, use PutPermission. For more information about partner event buses, see CreateEventBus.

    Args:
        name(str, optional): The name or ARN of the event bus to show details for. If you omit this, the default event bus is displayed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.bus.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.bus.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="describe_event_bus",
        op_kwargs={"Name": name},
    )


async def list_all(
    hub, ctx, name_prefix: str = None, next_token: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the event buses in your account, including the default event bus, custom event buses, and partner event buses.

    Args:
        name_prefix(str, optional): Specifying this limits the results to only those event buses with names that start with the specified prefix. Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        limit(int, optional): Specifying this limits the number of results returned by this operation. The operation also returns a NextToken which you can use in a subsequent operation to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.event.bus.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.event.bus.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="list_event_buses",
        op_kwargs={"NamePrefix": name_prefix, "NextToken": next_token, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def confirm(
    hub, ctx, instance_id: str, product_code: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Determines whether a product code is associated with an instance. This action can only be used by the owner of the product code. It is useful when a product code owner must verify whether another user's instance is eligible for support.

    Args:
        instance_id(str): The ID of the instance.
        product_code(str): The product code. This must be a product code that you own.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.product_instance.confirm(
                ctx, instance_id=value, product_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.product_instance.confirm instance_id=value, product_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="confirm_product_instance",
        op_kwargs={
            "InstanceId": instance_id,
            "ProductCode": product_code,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    DescribeEndpoints returns a list of available endpoints to make Timestream API calls against. This API is available through both Write and Query. Because Timestream’s SDKs are designed to transparently work with the service’s architecture, including the management and mapping of the service endpoints, it is not recommended that you use this API unless:   Your application uses a programming language that does not yet have SDK support   You require better control over the client-side implementation   For detailed information on how to use DescribeEndpoints, see The Endpoint Discovery Pattern and REST APIs.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.timestream_query.endpoint.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.timestream_query.endpoint.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="timestream-query",
        operation="describe_endpoints",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, resource_id: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds tags to an Amazon EMR resource. Tags make it easier to associate clusters in various ways, such as grouping clusters to track your Amazon EMR resource allocation costs. For more information, see Tag Clusters.

    Args:
        resource_id(str): The Amazon EMR resource identifier to which tags will be added. This value must be a cluster identifier.
        tags(List): A list of tags to associate with a cluster and propagate to EC2 instances. Tags are user-defined key-value pairs that consist of a required key string with a maximum of 128 characters, and an optional value string with a maximum of 256 characters.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.tags.add(ctx, resource_id=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.tags.add resource_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="add_tags",
        op_kwargs={"ResourceId": resource_id, "Tags": tags},
    )


async def remove(hub, ctx, resource_id: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from an Amazon EMR resource. Tags make it easier to associate clusters in various ways, such as grouping clusters to track your Amazon EMR resource allocation costs. For more information, see Tag Clusters.  The following example removes the stack tag with value Prod from a cluster:

    Args:
        resource_id(str): The Amazon EMR resource identifier from which tags will be removed. This value must be a cluster identifier.
        tag_keys(List): A list of tag keys to remove from a resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.tags.remove(ctx, resource_id=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.tags.remove resource_id=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="remove_tags",
        op_kwargs={"ResourceId": resource_id, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    workbook_id: str,
    table_id: str,
    rows_to_update: List,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The BatchUpdateTableRows API allows you to update one or more rows in a table in a workbook.   You can specify the values to set in some or all of the columns in the table for the specified rows. If a column is not explicitly specified in a particular row, then that column will not be updated for that row. To clear out the data in a specific cell, you need to set the value as an empty string ("").

    Args:
        workbook_id(str): The ID of the workbook where the rows are being updated.  If a workbook with the specified id could not be found, this API throws ResourceNotFoundException. .
        table_id(str): The ID of the table where the rows are being updated.  If a table with the specified id could not be found, this API throws ResourceNotFoundException. .
        rows_to_update(List):  The list of rows to update in the table. Each item in this list needs to contain the row id to update along with the map of column id to cell values for each column in that row that needs to be updated. You need to specify at least one row in this list, and for each row, you need to specify at least one column to update.   Note that if one of the row or column ids in the request does not exist in the table, then the request fails and no updates are made to the table. .
        client_request_token(str, optional):  The request token for performing the update action. Request tokens help to identify duplicate requests. If a call times out or fails due to a transient error like a failed network connection, you can retry the call with the same request token. The service ensures that if the first call using that request token is successfully performed, the second call will not perform the action again.   Note that request tokens are valid only for a few minutes. You cannot use request tokens to dedupe requests spanning hours or days. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.honeycode.update_table_row.batch(
                ctx, workbook_id=value, table_id=value, rows_to_update=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.honeycode.update_table_row.batch workbook_id=value, table_id=value, rows_to_update=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="honeycode",
        operation="batch_update_table_rows",
        op_kwargs={
            "workbookId": workbook_id,
            "tableId": table_id,
            "rowsToUpdate": rows_to_update,
            "clientRequestToken": client_request_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(hub, ctx, resource_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an entire resource tree. This operation will delete the parent resource and its child resources. Child resources are resources that were created from another resource. For example, when a forecast is generated from a predictor, the forecast is the child resource and the predictor is the parent resource. Amazon Forecast resources possess the following parent-child resource hierarchies:    Dataset: dataset import jobs    Dataset Group: predictors, predictor backtest export jobs, forecasts, forecast export jobs    Predictor: predictor backtest export jobs, forecasts, forecast export jobs    Forecast: forecast export jobs     DeleteResourceTree will only delete Amazon Forecast resources, and will not delete datasets or exported files stored in Amazon S3.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the parent resource to delete. All child resources of the parent resource will also be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.resource.tree.delete(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.resource.tree.delete resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="delete_resource_tree",
        op_kwargs={"ResourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, name: str, description: str = None, vpc_config: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Selenium testing project. Projects are used to track TestGridSession instances.

    Args:
        name(str): Human-readable name of the Selenium testing project.
        description(str, optional): Human-readable description of the project. Defaults to None.
        vpc_config(Dict, optional): The VPC security groups and subnets that are attached to a project. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.test.grid.project.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.test.grid.project.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="create_test_grid_project",
        op_kwargs={"name": name, "description": description, "vpcConfig": vpc_config},
    )


async def delete(hub, ctx, project_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a Selenium testing project and all content generated under it.   You cannot undo this operation.   You cannot delete a project if it has active sessions.

    Args:
        project_arn(str): The ARN of the project to delete, from CreateTestGridProject or ListTestGridProjects.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.test.grid.project.delete(ctx, project_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.test.grid.project.delete project_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="delete_test_grid_project",
        op_kwargs={"projectArn": project_arn},
    )


async def get(hub, ctx, project_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a Selenium testing project.

    Args:
        project_arn(str): The ARN of the Selenium testing project, from either CreateTestGridProject or ListTestGridProjects.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.test.grid.project.get(ctx, project_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.test.grid.project.get project_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_test_grid_project",
        op_kwargs={"projectArn": project_arn},
    )


async def list_all(hub, ctx, max_result: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of all Selenium testing projects in your account.

    Args:
        max_result(int, optional): Return no more than this number of results. Defaults to None.
        next_token(str, optional): From a response, used to continue a paginated listing. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.test.grid.project.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.test.grid.project.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_test_grid_projects",
        op_kwargs={"maxResult": max_result, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    project_arn: str,
    name: str = None,
    description: str = None,
    vpc_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Change details of a project.

    Args:
        project_arn(str): ARN of the project to update.
        name(str, optional): Human-readable name for the project. Defaults to None.
        description(str, optional): Human-readable description for the project. Defaults to None.
        vpc_config(Dict, optional): The VPC security groups and subnets that are attached to a project. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.test.grid.project.update(ctx, project_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.test.grid.project.update project_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="update_test_grid_project",
        op_kwargs={
            "projectArn": project_arn,
            "name": name,
            "description": description,
            "vpcConfig": vpc_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def accept(hub, ctx, domain_name: str, password: str) -> Dict:
    r"""
    **Autogenerated function**

    Accepts the transfer of a domain from another AWS account to the current AWS account. You initiate a transfer between AWS accounts using TransferDomainToAnotherAwsAccount.  Use either ListOperations or GetOperationDetail to determine whether the operation succeeded. GetOperationDetail provides additional information, for example, Domain Transfer from Aws Account 111122223333 has been cancelled.

    Args:
        domain_name(str): The name of the domain that was specified when another AWS account submitted a TransferDomainToAnotherAwsAccount request. .
        password(str): The password that was returned by the TransferDomainToAnotherAwsAccount request. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.transfer.from_another_aws_account.accept(
                ctx, domain_name=value, password=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.transfer.from_another_aws_account.accept domain_name=value, password=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="accept_domain_transfer_from_another_aws_account",
        op_kwargs={"DomainName": domain_name, "Password": password},
    )


async def reject(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Rejects the transfer of a domain from another AWS account to the current AWS account. You initiate a transfer between AWS accounts using TransferDomainToAnotherAwsAccount.  Use either ListOperations or GetOperationDetail to determine whether the operation succeeded. GetOperationDetail provides additional information, for example, Domain Transfer from Aws Account 111122223333 has been cancelled.

    Args:
        domain_name(str): The name of the domain that was specified when another AWS account submitted a TransferDomainToAnotherAwsAccount request. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.transfer.from_another_aws_account.reject(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.transfer.from_another_aws_account.reject domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="reject_domain_transfer_from_another_aws_account",
        op_kwargs={"DomainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, resource_arn: str, tags: Dict = None) -> None:
    r"""
    **Autogenerated function**

    Create tags for a resource

    Args:
        resource_arn(str): Placeholder documentation for __string.
        tags(Dict, optional): Placeholder documentation for Tags. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.tags.init.create(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.tags.init.create resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="create_tags",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def delete(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes tags for a resource

    Args:
        resource_arn(str): Placeholder documentation for __string.
        tag_keys(List): An array of tag keys to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.medialive.tags.init.delete(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.medialive.tags.init.delete resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="medialive",
        operation="delete_tags",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(
    hub, ctx, detector_id: str, master_id: str, invitation_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts the invitation to be monitored by a GuardDuty administrator account.

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty member account.
        master_id(str): The account ID of the GuardDuty administrator account whose invitation you're accepting.
        invitation_id(str): The value that is used to validate the administrator account to the member account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.invitation.init.accept(
                ctx, detector_id=value, master_id=value, invitation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.invitation.init.accept detector_id=value, master_id=value, invitation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="accept_invitation",
        op_kwargs={
            "DetectorId": detector_id,
            "MasterId": master_id,
            "InvitationId": invitation_id,
        },
    )


async def decline(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Declines invitations sent to the current member account by AWS accounts specified by their account IDs.

    Args:
        account_ids(List): A list of account IDs of the AWS accounts that sent invitations to the current member account that you want to decline invitations from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.invitation.init.decline(ctx, account_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.invitation.init.decline account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="decline_invitations",
        op_kwargs={"AccountIds": account_ids},
    )


async def delete_multiple(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes invitations sent to the current member account by AWS accounts specified by their account IDs.

    Args:
        account_ids(List): A list of account IDs of the AWS accounts that sent invitations to the current member account that you want to delete invitations from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.invitation.init.delete_multiple(
                ctx, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.invitation.init.delete_multiple account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="delete_invitations",
        op_kwargs={"AccountIds": account_ids},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all GuardDuty membership invitations that were sent to the current AWS account.

    Args:
        max_results(int, optional): You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.invitation.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.invitation.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="list_invitations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, resource_collection_type: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns lists AWS resources that are of the specified resource collection type. The one type of AWS resource collection supported is AWS CloudFormation stacks. DevOps Guru can be configured to analyze only the AWS resources that are defined in the stacks. You can specify up to 500 AWS CloudFormation stacks.

    Args:
        resource_collection_type(str):  The type of AWS resource collections to return. The one valid value is CLOUD_FORMATION for AWS CloudFormation stacks. .
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.resource_collection.init.get(
                ctx, resource_collection_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.resource_collection.init.get resource_collection_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="get_resource_collection",
        op_kwargs={
            "ResourceCollectionType": resource_collection_type,
            "NextToken": next_token,
        },
    )


async def update(hub, ctx, action: str, resource_collection: Dict) -> Dict:
    r"""
    **Autogenerated function**

     Updates the collection of resources that DevOps Guru analyzes. The one type of AWS resource collection supported is AWS CloudFormation stacks. DevOps Guru can be configured to analyze only the AWS resources that are defined in the stacks. You can specify up to 500 AWS CloudFormation stacks. This method also creates the IAM role required for you to use DevOps Guru.

    Args:
        action(str):  Specifies if the resource collection in the request is added or deleted to the resource collection. .
        resource_collection(Dict):  Contains information used to update a collection of AWS resources. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.resource_collection.init.update(
                ctx, action=value, resource_collection=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.resource_collection.init.update action=value, resource_collection=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="update_resource_collection",
        op_kwargs={"Action": action, "ResourceCollection": resource_collection},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, retiring_principal: str, limit: int = None, marker: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all grants in the AWS account and Region that have the specified retiring principal. For more information about grants, see Grants in the  AWS Key Management Service Developer Guide . You can specify any principal in your AWS account. The grants that are returned include grants for CMKs in your AWS account and other AWS accounts. You might use this operation to determine which grants you may retire. To retire a grant, use the RetireGrant operation.  Cross-account use: You must specify a principal in your AWS account. However, this operation can return grants in any AWS account. You do not need kms:ListRetirableGrants permission (or any other additional permission) in any AWS account other than your own.  Required permissions: kms:ListRetirableGrants (IAM policy) in your AWS account.  Related operations:     CreateGrant     ListGrants     RetireGrant     RevokeGrant

    Args:
        limit(int, optional): Use this parameter to specify the maximum number of items to return. When this value is present, AWS KMS does not return more than the specified number of items, but it might return fewer. This value is optional. If you include a value, it must be between 1 and 100, inclusive. If you do not include a value, it defaults to 50. Defaults to None.
        marker(str, optional): Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextMarker from the truncated response you just received. Defaults to None.
        retiring_principal(str): The retiring principal for which to list grants. Enter a principal in your AWS account. To specify the retiring principal, use the Amazon Resource Name (ARN) of an AWS principal. Valid AWS principals include AWS accounts (root), IAM users, federated users, and assumed role users. For examples of the ARN syntax for specifying a principal, see AWS Identity and Access Management (IAM) in the Example ARNs section of the Amazon Web Services General Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.retirable_grant.list_all(ctx, retiring_principal=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.retirable_grant.list_all retiring_principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="list_retirable_grants",
        op_kwargs={
            "Limit": limit,
            "Marker": marker,
            "RetiringPrincipal": retiring_principal,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    resource_type: str = None,
    resource_id: str = None,
    compliance_types: List = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Indicates whether the specified AWS resources are compliant. If a resource is noncompliant, this action returns the number of AWS Config rules that the resource does not comply with. A resource is compliant if it complies with all the AWS Config rules that evaluate it. It is noncompliant if it does not comply with one or more of these rules. If AWS Config has no current evaluation results for the resource, it returns INSUFFICIENT_DATA. This result might indicate one of the following conditions about the rules that evaluate the resource:   AWS Config has never invoked an evaluation for the rule. To check whether it has, use the DescribeConfigRuleEvaluationStatus action to get the LastSuccessfulInvocationTime and LastFailedInvocationTime.   The rule's AWS Lambda function is failing to send evaluation results to AWS Config. Verify that the role that you assigned to your configuration recorder includes the config:PutEvaluations permission. If the rule is a custom rule, verify that the AWS Lambda execution role includes the config:PutEvaluations permission.   The rule's AWS Lambda function has returned NOT_APPLICABLE for all evaluation results. This can occur if the resources were deleted or removed from the rule's scope.

    Args:
        resource_type(str, optional): The types of AWS resources for which you want compliance information (for example, AWS::EC2::Instance). For this action, you can specify that the resource type is an AWS account by specifying AWS::::Account. Defaults to None.
        resource_id(str, optional): The ID of the AWS resource for which you want compliance information. You can specify only one resource ID. If you specify a resource ID, you must also specify a type for ResourceType. Defaults to None.
        compliance_types(List, optional): Filters the results by compliance. The allowed values are COMPLIANT, NON_COMPLIANT, and INSUFFICIENT_DATA. Defaults to None.
        limit(int, optional): The maximum number of evaluation results returned on each page. The default is 10. You cannot specify a number greater than 100. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.compliance.by.resource.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.compliance.by.resource.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_compliance_by_resource",
        op_kwargs={
            "ResourceType": resource_type,
            "ResourceId": resource_id,
            "ComplianceTypes": compliance_types,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "client_property"


async def describe_all(hub, ctx, resource_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes one or more specified Amazon WorkSpaces clients.

    Args:
        resource_ids(List): The resource identifier, in the form of directory IDs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.client_property_.describe_all(ctx, resource_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.client_property.describe_all resource_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_client_properties",
        op_kwargs={"ResourceIds": resource_ids},
    )


async def modify(hub, ctx, resource_id: str, client_properties: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the properties of the specified Amazon WorkSpaces clients.

    Args:
        resource_id(str): The resource identifiers, in the form of directory IDs.
        client_properties(Dict): Information about the Amazon WorkSpaces client.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.client_property_.modify(
                ctx, resource_id=value, client_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.client_property.modify resource_id=value, client_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="modify_client_properties",
        op_kwargs={"ResourceId": resource_id, "ClientProperties": client_properties},
    )
